<?php

namespace BitGoblin\Colossus\Controllers;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Routing\RouteContext;
use Slim\Views\Twig;
use BitGoblin\Colossus\Models\Component;

class ComponentController extends Controller {

  public function getIndex(Request $request, Response $response): Response {
    // redirect the user back to the home page
    $routeContext = RouteContext::fromRequest($request);
    $routeParser = $routeContext->getRouteParser();
    return $response
      ->withHeader('Location', $routeParser->urlFor('component.list'))
      ->withStatus(302);
  }

  public function getList(Request $request, Response $response): Response {
    $components = Component::orderByDesc('updated_at')->get();

    $view = Twig::fromRequest($request);
    return $view->render($response, 'component/list.twig', [
      'components' => $components,
    ]);
  }

  public function getView(Request $request, Response $response, array $args): Response {
    $component = Component::where('id', $args['component_id'])->first();

    $view = Twig::fromRequest($request);
    return $view->render($response, 'component/view.twig', [
      'component' => $component,
    ]);
  }

  public function getAdd(Request $request, Response $response): Response {
    $view = Twig::fromRequest($request);
    return $view->render($response, 'component/add.twig');
  }

  public function postAdd(Request $request, Response $response): Response {
    $params = (array)$request->getParsedBody();

    $component = new Component;
    $component->name = $params['component_name'];
    $component->type = $params['component_type'];

    $component->save();

    // redirect the user back to the home page
    $routeContext = RouteContext::fromRequest($request);
    $routeParser = $routeContext->getRouteParser();
    return $response
      ->withHeader('Location', $routeParser->urlFor('component.list'))
      ->withStatus(302);
  }

}
